@@ -5,7 +5,7 @@ from typing import Dict, List
 
 import numpy as np
 from lazy import lazy
-from tqdm import tqdm
+from tqdm.auto import tqdm
 
 from evobench.model.population import Population
 from evobench.model.solution import Solution
@@ -18,11 +18,17 @@ class Benchmark(ABC):
     inherit from this class.
     """
 
-    def __init__(self, shuffle: bool = False, multiprocessing: bool = False):
+    def __init__(
+        self,
+        shuffle: bool = False,
+        multiprocessing: bool = False,
+        verbose: int = 0
+    ):
         super(Benchmark, self).__init__()
         self.ffe = 0
         self.SHUFFLE = shuffle
         self.MULTIPROCESSING = multiprocessing
+        self.VERBOSE = verbose
 
     @abstractproperty
     def genome_size(self) -> int:
@@ -76,8 +82,13 @@ class Benchmark(ABC):
         size = int(size)
         solutions = []
 
-        tqdm.write('\n')
-        for _ in tqdm(range(size), desc='Initializing population'):
+        iterator = range(size)
+
+        if self.VERBOSE:
+            tqdm.write('\n')
+            iterator = tqdm(iterator, desc='Initializing population')
+
+        for _ in iterator:
             genome = self.random_solution().genome
 
             solution = Solution(genome)
@@ -96,7 +107,7 @@ class Benchmark(ABC):
 
         return Solution(genome)
 
-    def evaluate_population(self, population: Population) -> np.ndarray:
+    def evaluate_population(self, population: Population):
         """
         Evaluates population of solutions.
 
@@ -112,36 +123,38 @@ class Benchmark(ABC):
             Order is the same as input population.
         """
 
-        tqdm.write('\n')
-        tqdm.write(
-            'Evaluating population of {} solutions'
-            .format(population.length)
-        )
-        tqdm.write('\n')
+        solutions = population.get_not_evaluated_solutions()
 
-        fitness = None
+        if self.VERBOSE:
+            tqdm.write('\n')
+            tqdm.write(
+                'Evaluating population of {} solutions'
+                .format(population.length)
+            )
+            tqdm.write('\n')
+
+            solutions = tqdm(solutions)
 
         if self.MULTIPROCESSING:
             pool = Pool()
             manager = Manager()
             lock = manager.RLock()
 
-            fitness = pool.map(
+            fitness_map = pool.map(
                 partial(
                     self.evaluate_solution,
                     gene_order=self.gene_order,
                     lock=lock
                 ),
-                tqdm(population.solutions)
+                solutions
             )
 
-        else:
-            fitness = [
-                self.evaluate_solution(solution)
-                for solution in tqdm(population.solutions)
-            ]
+            for solution, fitness in zip(solutions, fitness_map):
+                solution.fitness = fitness
 
-        return np.array(fitness)
+        else:
+            for solution in solutions:
+                solution.fitness = self.evaluate_solution(solution)
 
     def evaluate_solution(
         self,
